@@ -639,11 +639,12 @@ create_pak_repo <- local({
   #
   # This is the compatiblity mapping for the older, generic repo URL:
   # ```
-  # /src/contrib                          -> linux/x86_64
-  # /bin/macosx/big-sur-arm64/contrib/4.1 -> darwin20/aarch64
-  # /bin/macosx/contrib/4.1               -> darwin17.0/x86_64
-  # /bin/macosx/el-capitan/contrib/3.6    -> darwin15.6.0/x86_64
-  # /bin/windows/contrib/4.1              -> mingw32/x86_64
+  # /src/contrib                           -> linux/x86_64
+  # /bin/macosx/big-sur-arm64/contrib/4.1  -> darwin20/aarch64
+  # /bin/macosx/contrib/4.1                -> darwin17.0/x86_64
+  # /bin/macosx/big-sur-x86_64/contrib/4.3 -> darwin20.0/x86_64
+  # /bin/macosx/el-capitan/contrib/3.6     -> darwin15.6.0/x86_64
+  # /bin/windows/contrib/4.1               -> mingw32/x86_64
   # ```
 
   links <- c(
@@ -684,6 +685,7 @@ create_pak_repo <- local({
     "mac.binary.big-sur-arm64/darwin20/aarch64/src/contrib" = "../../../../../darwin20/aarch64",
     "mac.binary/darwin17.0/x86_64/src/contrib" = "../../../../../darwin17.0/x86_64",
     "mac.binary.el-capitan/darwin15.6.0/x86_64/src/contrib" = "../../../../../darwin15.6.0/x86_64",
+    "mac.binary.big-sur-x86_64/darwin20/x86_64/src/contrib" = "../../../../../darwin20/x86_64",
 
     "win.binary/mingw32/x86_64/bin/windows/contrib/3.4" = "../../../../../../../mingw32/x86_64",
     "win.binary/mingw32/x86_64/bin/windows/contrib/3.5" = "../../../../../../../mingw32/x86_64",
@@ -698,6 +700,8 @@ create_pak_repo <- local({
     "mac.binary.big-sur-arm64/darwin20/aarch64/bin/macosx/big-sur-arm64/contrib/4.2" = "../../../../../../../../darwin20/aarch64",
     "mac.binary.big-sur-arm64/darwin20/aarch64/bin/macosx/big-sur-arm64/contrib/4.3" = "../../../../../../../../darwin20/aarch64",
     "mac.binary.big-sur-arm64/darwin20/aarch64/bin/macosx/big-sur-arm64/contrib/4.4" = "../../../../../../../../darwin20/aarch64",
+    "mac.binary.big-sur-x86_64/darwin20/x86_64/bin/macosx/big-sur-x86_64/contrib/4.3" = "../../../../../../../../darwin20/x86_64",
+    "mac.binary.big-sur-x86_64/darwin20/x86_64/bin/macosx/big-sur-x86_64/contrib/4.4" = "../../../../../../../../darwin20/x86_64",
     "mac.binary/darwin17.0/x86_64/bin/macosx/contrib/4.0" = "../../../../../../../darwin17.0/x86_64",
     "mac.binary/darwin17.0/x86_64/bin/macosx/contrib/4.1" = "../../../../../../../darwin17.0/x86_64",
     "mac.binary/darwin17.0/x86_64/bin/macosx/contrib/4.2" = "../../../../../../../darwin17.0/x86_64",
@@ -730,6 +734,8 @@ create_pak_repo <- local({
     "bin/macosx/el-capitan/contrib/3.4" = "../../../../../darwin15.6.0/x86_64",
     "bin/macosx/el-capitan/contrib/3.5" = "../../../../../darwin15.6.0/x86_64",
     "bin/macosx/el-capitan/contrib/3.6" = "../../../../../darwin15.6.0/x86_64",
+    "bin/macosx/big-sur-x86_64/contrib/4.3" = "../../../../../darwin20/x86_64",
+    "bin/macosx/big-sur-x86_64/contrib/4.4" = "../../../../../darwin20/x86_64",
 
     "src/contrib" = "../../linux/x86_64"
   )
